import"./jwt-decode.esm-ChM3M22o.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="71d6409a-fc69-45f3-8942-7969c58a8aec",e._sentryDebugIdIdentifier="sentry-dbid-71d6409a-fc69-45f3-8942-7969c58a8aec")}catch{}})();const d=e=>{try{return new URL(e),!0}catch{return!1}},o=(e,r)=>{if(!Object.keys(r).length)return e;const t=new URL(e),n=new URLSearchParams(t.search);return Object.entries(r).forEach(([a,s])=>{t.searchParams.delete(a),n.set(a,s)}),`${t.origin}${t.pathname}?${n.toString()}`};export{d as i,o as m};
//# sourceMappingURL=url-Crd93M85.js.map
