import{N as c}from"./Navbar-BNLC8bJL.js";import{e as d,ak as u,b as a,l,a6 as f,f as _,g as y,v as p,k as I,aO as b}from"./jwt-decode.esm-ChM3M22o.js";import"./logo-BiWG9_W5.js";import"./AbstraButton.vue_vue_type_script_setup_true_lang-CoFoqH_2.js";import"./constants-D_Yr6O9R.js";import"./PhCaretDown.vue-zjtFelW5.js";import"./PhPencilSimple.vue-m-RAhCzi.js";import"./router-DUAdFgqq.js";import"./ts.worker-zLJCVq5f.js";import"./organization-CWjfONjg.js";import"./tables-CvnWXc7K.js";import"./string-Dy2mpz43.js";import"./keyboard-CgVo5FAf.js";import"./os-BCFfBT8V.js";import"./projectStore-B-gq0jU3.js";import"./project-BdwT3Wkl.js";import"./organizationSwitcher-C6X7uQHU.js";import"./cascaderStore-DhQZxWfu.js";import"./CreateProjectModal.vue_vue_type_script_setup_true_lang-ColNfXhy.js";import"./member-bi6qXQah.js";import"./index-Dtf5LVFG.js";import"./index-BdcZw4V5.js";import"./CreateTableModal.vue_vue_type_script_setup_true_lang-aGRhGvlA.js";import"./PhNotePencil.vue-B1bYp4fN.js";import"./PhSignOut.vue-B3lrMMRp.js";import"./index-B2Ygu5QQ.js";import"./index-B3BfoPaT.js";import"./PhPlus.vue-B2mnEdCk.js";import"./omniChatStore-DvPgQXhP.js";import"./files-C-fxyCpF.js";import"./contracts.generated-DtiYS5k7.js";import"./runnerData-Ddr8QC8K.js";import"./url-Crd93M85.js";import"./colorHelpers-B7xTgS8f.js";import"./uuid-BbT-vu21.js";import"./PhCopySimple.vue-BAIZwx9P.js";import"./PhSparkle.vue-BILVDL7V.js";import"./index-DdnT1udJ.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[o]="83b02225-a85f-47df-9617-c13fce260c98",r._sentryDebugIdIdentifier="sentry-dbid-83b02225-a85f-47df-9617-c13fce260c98")}catch{}})();const v={class:"console-layout"},g={class:"console-content"},w=d({__name:"ConsoleLayout",setup(r){const o=u(),s=a(()=>!!o.params.projectId),n=a(()=>{const t=o.meta.pageNameKey;if(t)return t.startsWith("i18n_")?l.translateIfFound(t,null):t}),m=a(()=>{const t=o.params.projectId,i=o.params.tableId,e=o.params.organizationId;if(t)return{projectId:t,tableId:i,currentPageName:n.value};if(e)return{organizationId:e}});return(t,i)=>{const e=f("RouterView");return y(),_("div",v,[p(c,{"use-cascader":!0,"cascader-props":m.value,"show-ai-sparkles":s.value},null,8,["cascader-props","show-ai-sparkles"]),I("div",g,[p(e)])])}}}),io=b(w,[["__scopeId","data-v-62f8634d"]]);export{io as default};
//# sourceMappingURL=ConsoleLayout-75psXsDa.js.map
