import{P as f}from"./PlayerNavbar-Bbqod8nM.js";import{e as _,ak as i,r as h,b,f as k,n as y,j as w,k as v,p as a,v as L,a6 as C,ag as I,g as c,aO as N}from"./jwt-decode.esm-ChM3M22o.js";import{u as V}from"./workspaceStore-Dn9srdAl.js";import"./userStore-bm3GzS2y.js";import"./metadata-2IMk9AIU.js";import"./PhCursorClick.vue-E71c6-QT.js";import"./PhHouse.vue-yLPdXJsl.js";import"./PhMagnifyingGlass.vue-D1ENgNsh.js";import"./PhWebhooksLogo.vue-CvJh5MDE.js";import"./LoadingOutlined-iszkyX3B.js";import"./PhSignOut.vue-B3lrMMRp.js";import"./index-B3BfoPaT.js";import"./runnerData-Ddr8QC8K.js";import"./url-Crd93M85.js";import"./colorHelpers-B7xTgS8f.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="cb8bab81-0737-4964-b13a-773f41dee24d",o._sentryDebugIdIdentifier="sentry-dbid-cb8bab81-0737-4964-b13a-773f41dee24d")}catch{}})();const B={class:"main-container"},D={class:"content"},P=_({__name:"Main",setup(o){const e=I(),t=V(),d=i().path,n=h(null),p=async({path:r,id:s})=>{n.value=s,await e.push({path:`/${r}`}),n.value=null},u=()=>{e.push({name:"playerLogin"})},l=()=>{e.push({name:"playerLogin"})},m=b(()=>!!i().meta.hideLogin);return(r,s)=>{const g=C("RouterView");return c(),k("div",B,[a(t).state.workspace?(c(),y(f,{key:0,"current-path":a(d),"hide-login":m.value,"runner-data":a(t).state.workspace,loading:n.value,"show-sidebar":a(t).state.currentPageType==="form",onNavigate:p,onLoginClick:l,onLogoutClick:u},null,8,["current-path","hide-login","runner-data","loading","show-sidebar"])):w("",!0),v("section",D,[L(g)])])}}}),H=N(P,[["__scopeId","data-v-61bdccea"]]);export{H as default};
//# sourceMappingURL=Main-TqQjvP0C.js.map
