import{C as t,_ as p}from"./View.vue_vue_type_script_setup_true_lang-mr8Px67R.js";import{e as i,n,g as s,p as m}from"./jwt-decode.esm-ChM3M22o.js";import{u as a}from"./projectStore-B-gq0jU3.js";import"./router-DUAdFgqq.js";import"./ts.worker-zLJCVq5f.js";import"./fetch-CQG_CHyE.js";import"./tables-CvnWXc7K.js";import"./string-Dy2mpz43.js";import"./SaveButton-DZhHNTTf.js";import"./ExclamationCircleOutlined-D1zIvrxK.js";import"./CrudView-BznjI8oX.js";import"./DocsButton.vue_vue_type_script_setup_true_lang-DzvrFaB3.js";import"./constants-D_Yr6O9R.js";import"./url-Crd93M85.js";import"./PhDotsThreeVertical.vue-Bs2p2fWf.js";import"./index-B2Ygu5QQ.js";import"./asyncComputed-x-5HqNbZ.js";import"./PhPencil.vue-BJyYvM9R.js";import"./useCodebaseEvents-DbnSyB44.js";import"./contracts.generated-DtiYS5k7.js";import"./index-Bqr3mRN_.js";import"./project-BdwT3Wkl.js";import"./organizationSwitcher-C6X7uQHU.js";import"./organization-CWjfONjg.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="811ad987-b710-4d48-8aa4-fe38ed0102d2",o._sentryDebugIdIdentifier="sentry-dbid-811ad987-b710-4d48-8aa4-fe38ed0102d2")}catch{}})();const z=i({__name:"EnvVars",setup(o){const r=a(),e=new t(r.projectId);return(d,f)=>(s(),n(p,{"env-var-repository":m(e),mode:"console"},null,8,["env-var-repository"]))}});export{z as default};
//# sourceMappingURL=EnvVars-BDyBNbvN.js.map
